@@ -26,6 +26,35 @@ class PrivatednsClient(AbstractClient):
     _service = 'privatedns'
 
 
+    def CreatePrivateDNSAccount(self, request):
+        """创建私有域解析账号
+
+        :param request: Request instance for CreatePrivateDNSAccount.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.CreatePrivateDNSAccountRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.CreatePrivateDNSAccountResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreatePrivateDNSAccount", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreatePrivateDNSAccountResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreatePrivateZone(self, request):
         """创建私有域
 
@@ -36,7 +65,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreatePrivateZone", params)
+            headers = request.headers
+            body = self.call("CreatePrivateZone", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreatePrivateZoneResponse()
@@ -64,7 +94,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreatePrivateZoneRecord", params)
+            headers = request.headers
+            body = self.call("CreatePrivateZoneRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreatePrivateZoneRecordResponse()
@@ -82,6 +113,35 @@ class PrivatednsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeletePrivateDNSAccount(self, request):
+        """删除私有域解析账号
+
+        :param request: Request instance for DeletePrivateDNSAccount.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.DeletePrivateDNSAccountRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.DeletePrivateDNSAccountResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeletePrivateDNSAccount", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeletePrivateDNSAccountResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeletePrivateZone(self, request):
         """删除私有域并停止解析
 
@@ -92,7 +152,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeletePrivateZone", params)
+            headers = request.headers
+            body = self.call("DeletePrivateZone", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeletePrivateZoneResponse()
@@ -120,7 +181,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeletePrivateZoneRecord", params)
+            headers = request.headers
+            body = self.call("DeletePrivateZoneRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeletePrivateZoneRecordResponse()
@@ -138,6 +200,35 @@ class PrivatednsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAccountVpcList(self, request):
+        """获取私有域解析账号的VPC列表
+
+        :param request: Request instance for DescribeAccountVpcList.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribeAccountVpcListRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.DescribeAccountVpcListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAccountVpcList", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAccountVpcListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAuditLog(self, request):
         """获取操作日志列表
 
@@ -148,7 +239,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAuditLog", params)
+            headers = request.headers
+            body = self.call("DescribeAuditLog", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAuditLogResponse()
@@ -176,7 +268,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDashboard", params)
+            headers = request.headers
+            body = self.call("DescribeDashboard", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDashboardResponse()
@@ -204,7 +297,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePrivateDNSAccountList", params)
+            headers = request.headers
+            body = self.call("DescribePrivateDNSAccountList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePrivateDNSAccountListResponse()
@@ -232,7 +326,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePrivateZone", params)
+            headers = request.headers
+            body = self.call("DescribePrivateZone", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePrivateZoneResponse()
@@ -260,7 +355,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePrivateZoneList", params)
+            headers = request.headers
+            body = self.call("DescribePrivateZoneList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePrivateZoneListResponse()
@@ -288,7 +384,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePrivateZoneRecordList", params)
+            headers = request.headers
+            body = self.call("DescribePrivateZoneRecordList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePrivateZoneRecordListResponse()
@@ -316,7 +413,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePrivateZoneService", params)
+            headers = request.headers
+            body = self.call("DescribePrivateZoneService", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePrivateZoneServiceResponse()
@@ -334,6 +432,35 @@ class PrivatednsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeQuotaUsage(self, request):
+        """查询额度使用情况
+
+        :param request: Request instance for DescribeQuotaUsage.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribeQuotaUsageRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.DescribeQuotaUsageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeQuotaUsage", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeQuotaUsageResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRequestData(self, request):
         """获取私有域解析请求量
 
@@ -344,7 +471,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRequestData", params)
+            headers = request.headers
+            body = self.call("DescribeRequestData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRequestDataResponse()
@@ -372,7 +500,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyPrivateZone", params)
+            headers = request.headers
+            body = self.call("ModifyPrivateZone", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyPrivateZoneResponse()
@@ -400,7 +529,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyPrivateZoneRecord", params)
+            headers = request.headers
+            body = self.call("ModifyPrivateZoneRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyPrivateZoneRecordResponse()
@@ -428,7 +558,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyPrivateZoneVpc", params)
+            headers = request.headers
+            body = self.call("ModifyPrivateZoneVpc", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyPrivateZoneVpcResponse()
@@ -456,7 +587,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SubscribePrivateZoneService", params)
+            headers = request.headers
+            body = self.call("SubscribePrivateZoneService", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SubscribePrivateZoneServiceResponse()
