@@ -56,6 +56,9 @@ FAILEDOPERATION_COMPONENTCLIENTUNPACK = 'FailedOperation.ComponentClientUnpack'
 # 请求(http请求)其他云服务失败。
 FAILEDOPERATION_COMPONENTCLINETHTTP = 'FailedOperation.ComponentClinetHttp'
 
+# 创建CLS日志集失败。
+FAILEDOPERATION_CREATECLSLOGSET = 'FailedOperation.CreateClsLogSet'
+
 # cvm创建节点报错。
 FAILEDOPERATION_CVMCOMMON = 'FailedOperation.CvmCommon'
 
@@ -77,15 +80,24 @@ FAILEDOPERATION_DFWGETUSGQUOTA = 'FailedOperation.DfwGetUSGQuota'
 # 查询主题集失败。
 FAILEDOPERATION_GETCLSLOGSET = 'FailedOperation.GetClsLogSet'
 
+# 获取CLS机器组失败。
+FAILEDOPERATION_GETCLSMACHINEGROUP = 'FailedOperation.GetClsMachineGroup'
+
 # 连接用户Kubernetes集群失败。
 FAILEDOPERATION_KUBECLIENTCONNECTION = 'FailedOperation.KubeClientConnection'
 
 # KubernetesAPI错误。
 FAILEDOPERATION_KUBECOMMON = 'FailedOperation.KubeCommon'
 
+# Kubernetes client建立失败。
+FAILEDOPERATION_KUBERNETESCLIENTBUILDERROR = 'FailedOperation.KubernetesClientBuildError'
+
 # 创建集群Client出错。
 FAILEDOPERATION_KUBERNETESCREATEOPERATIONERROR = 'FailedOperation.KubernetesCreateOperationError'
 
+# Kubernetes Delete 操作错误。
+FAILEDOPERATION_KUBERNETESDELETEOPERATIONERROR = 'FailedOperation.KubernetesDeleteOperationError'
+
 # Kubernetes未知错误。
 FAILEDOPERATION_KUBERNETESINTERNAL = 'FailedOperation.KubernetesInternal'
 
@@ -128,6 +140,9 @@ FAILEDOPERATION_VPCCOMMON = 'FailedOperation.VpcCommon'
 # 未发现vpc记录。
 FAILEDOPERATION_VPCRECODRNOTFOUND = 'FailedOperation.VpcRecodrNotFound'
 
+# 白名单错误。
+FAILEDOPERATION_WHITELISTUNEXPECTEDERROR = 'FailedOperation.WhitelistUnexpectedError'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -356,9 +371,6 @@ INVALIDPARAMETER_CIDRCONFLICTWITHVPCCIDR = 'InvalidParameter.CidrConflictWithVpc
 # 创建的路由与VPC下已存在的全局路由产生冲突。
 INVALIDPARAMETER_CIDRCONFLICTWITHVPCGLOBALROUTE = 'InvalidParameter.CidrConflictWithVpcGlobalRoute'
 
-# CIDR无效。
-INVALIDPARAMETER_CIDRINVALI = 'InvalidParameter.CidrInvali'
-
 # 参数错误，CIDR不符合规范。
 INVALIDPARAMETER_CIDRINVALID = 'InvalidParameter.CidrInvalid'
 
